==> 0.0.4.tar.gz: lib/net_dio_manager.dart <==
import 'package:dio/dio.dart';

class HTTPManager {
  Dio _dio = Dio();
  @deprecated
  List<CancelToken> cancelTokenList = <CancelToken>[];
  Map<String, CancelToken> _cancelTokenMap = {};
  @deprecated
  static HTTPManager? _instance;

  HTTPManager._internal();

  @deprecated
  factory HTTPManager.getInstance() => _getInstance();

  @deprecated
  static _getInstance() {
    if (_instance == null) {
      _instance = HTTPManager._internal();
    }
    return _instance;
  }

  Dio get dio => _dio;

  HTTPManager._();

  static HTTPManager get instance => HTTPManager._();

  void init(BaseOptions options, {List<Interceptor>? interceptors}) {
    _dio.options = options;
    if (interceptors != null) {
      _dio.interceptors.addAll(interceptors);
    }
  }

  @deprecated
  void addCancelToken(CancelToken cancelToken) {
    cancelTokenList.add(cancelToken);
  }

  @deprecated
  void removeCancelToken(CancelToken cancelToken) {
    cancelTokenList.remove(cancelToken);
  }

  @deprecated
  void removeAllCancelToken() {
    cancelTokenList.forEach((element) {
      element.cancel();
    });
    cancelTokenList.clear();
  }

  @deprecated
  Future<Response<T>> get<T>(String path, {Map<String, dynamic>? queryParameters, Options? options, CancelToken? cancelToken, ProgressCallback? onReceiveProgress}) {
    cancelToken = cancelToken ?? CancelToken();
    addCancelToken(cancelToken);
    var future = _dio.get<T>(path, queryParameters: queryParameters, options: options, cancelToken: cancelToken, onReceiveProgress: onReceiveProgress);
    removeCancelToken(cancelToken);
    return future;
  }

  @deprecated
  Future<Response<T>> post<T>(String path, {data, Map<String, dynamic>? queryParameters, Options? options, CancelToken? cancelToken, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) {
    cancelToken = cancelToken ?? CancelToken();
    addCancelToken(cancelToken);
    Future<Response<T>> future = _dio.post(path, data: data, queryParameters: queryParameters, options: options, cancelToken: cancelToken, onSendProgress: onReceiveProgress, onReceiveProgress: onReceiveProgress);
    removeCancelToken(cancelToken);
    return future;
  }

  String _prefixCancelKey = "_dio_life_";

  String _subjoinKey(dynamic key) => "${key.toString()}$_prefixCancelKey${DateTime.now().millisecondsSinceEpoch}";

  /// 绑定 CancelToken
  CancelToken addLife(dynamic life) {
    var key = _subjoinKey(life);
    CancelToken cancelToken =CancelToken();
    _cancelTokenMap[key] = cancelToken;
    return cancelToken;
  }

  /// 取消请求
  bool cancelLife(dynamic life) {
    var r = false;
    var keys = List.of(_cancelTokenMap.keys);
    keys.forEach((element) {
      if (element.startsWith("${life.toString()}$_prefixCancelKey")) {
        var cancelToken = _cancelTokenMap[element];
        cancelToken?.cancel();
        _cancelTokenMap.remove(element);
        r = true;
      }
    });
    return r;
  }

  void _removeLife(dynamic life) {
    var keys = List.of(_cancelTokenMap.keys);
    keys.forEach((element) {
      if (element.startsWith("${life.toString()}$_prefixCancelKey")) {
        _cancelTokenMap.remove(element);
      }
    });
  }

  /// 取消当前的全部请求
  void clearLife() {
    _cancelTokenMap.values.forEach((element) => element.cancel());
    _cancelTokenMap.clear();
  }

  /*

class RequestWrap {
  final dynamic life;

  const RequestWrap(this.life);
}

extension RequestWrapExt on RequestWrap {
  Future<dynamic> getResult() async {
    HTTPManager.getInstance().getAsync("path", life: this.life);
    return "";
  }

  Future<dynamic> postUser() async {
    HTTPManager.getInstance().postAsync("path", life: this.life);
    return "";
  }
}

extension DioLifeOnBloc on IBlocBase {
  RequestWrap get api => RequestWrap(this);
}

extension DioLifeOnState on State {
  RequestWrap get api => RequestWrap(this);
}
  */

  Future<Response<T>> getAsync<T>(String path, {Map<String, dynamic>? queryParameters, Options? options, dynamic life, ProgressCallback? onReceiveProgress}) async {
    if (life == null) life = DateTime.now().millisecondsSinceEpoch.toString();
    var cancelToken = addLife(life);
    Response<T> future = await _dio.get<T>(path, queryParameters: queryParameters, options: options, onReceiveProgress: onReceiveProgress, cancelToken: cancelToken);
    _removeLife(life);
    return future;
  }

  Future<Response<T>> postAsync<T>(String path, {data, Options? options, dynamic life, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) async {
    if (life == null) life = DateTime.now().millisecondsSinceEpoch.toString();
    var cancelToken = addLife(life);
    Response<T> future = await _dio.post(path, data: data, options: options, onSendProgress: onReceiveProgress, onReceiveProgress: onReceiveProgress, cancelToken: cancelToken);
    _removeLife(life);
    return future;
  }
}

mixin DioLife {}

==> 0.0.8.tar.gz: lib/net_dio_manager.dart <==
import 'package:dio/dio.dart';

class HTTPManager {
  Dio _dio = Dio();

  Map<String, CancelToken> _cancelTokenMap = {};

  static HTTPManager? _instance;

  HTTPManager._();


  static _getInstance() {
    if (_instance == null) {
      _instance = HTTPManager._();
    }
    return _instance;
  }

  Dio get dio => _dio;

  static HTTPManager get instance => _getInstance();

  void init(BaseOptions options, {List<Interceptor>? interceptors}) {
    _dio.options = options;
    if (interceptors != null) {
      _dio.interceptors.addAll(interceptors);
    }
  }

  String _prefixCancelKey = "_dio_life_";

  String _subjoinKey(dynamic key) => "${key.toString()}$_prefixCancelKey${DateTime.now().millisecondsSinceEpoch}";

  /// 绑定 CancelToken
  CancelToken addLife(dynamic life) {
    var key = _subjoinKey(life);
    CancelToken cancelToken = CancelToken();
    _cancelTokenMap[key] = cancelToken;
    return cancelToken;
  }

  /// 取消请求
  bool cancelLife(dynamic life) {
    var r = false;
    var keys = List.of(_cancelTokenMap.keys);
    keys.forEach((element) {
      if (element.startsWith("${life.toString()}$_prefixCancelKey")) {
        var cancelToken = _cancelTokenMap[element];
        cancelToken?.cancel();
        _cancelTokenMap.remove(element);
        r = true;
      }
    });
    return r;
  }

  void _removeLife(dynamic life) {
    var keys = List.of(_cancelTokenMap.keys);
    keys.forEach((element) {
      if (element.startsWith("${life.toString()}$_prefixCancelKey")) {
        _cancelTokenMap.remove(element);
      }
    });
  }

  /// 取消当前的全部请求
  void clearLife() {
    _cancelTokenMap.values.forEach((element) => element.cancel());
    _cancelTokenMap.clear();
  }


  Future<Response<T>> getAsync<T>(String path, {Map<String, dynamic>? queryParameters, Options? options, dynamic life, ProgressCallback? onReceiveProgress}) async {
    if (life == null) life = DateTime.now().millisecondsSinceEpoch.toString();
    var cancelToken = addLife(life);
    Response<T> future = await _dio.get<T>(path, queryParameters: queryParameters, options: options, onReceiveProgress: onReceiveProgress, cancelToken: cancelToken);
    _removeLife(life);
    return future;
  }

  Future<Response<T>> postAsync<T>(String path, {data, Options? options, dynamic life, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) async {
    if (life == null) life = DateTime.now().millisecondsSinceEpoch.toString();
    var cancelToken = addLife(life);
    Response<T> future = await _dio.post(path, data: data, options: options, onSendProgress: onReceiveProgress, onReceiveProgress: onReceiveProgress, cancelToken: cancelToken);
    _removeLife(life);
    return future;
  }
}

mixin DioLife {}

extension MapToFormData on Map<String, dynamic> {
  FormData get toFormData => FormData.fromMap(this);
}
